import React, { MutableRefObject } from 'react';
import { ReactNode } from 'react';
import { FormInstance, FormProps } from 'antd';
interface ColumnProps {
    title: string;
    dataIndex: string;
    key?: string | number;
    width?: number;
    ellipsis?: Boolean;
    showTitle?: Boolean;
    copyable?: Boolean;
    fixed?: 'left' | 'right';
    hideInTable?: boolean;
    hideInSearch?: boolean;
    search?: {
        transform?: (value: any) => Record<string, any>;
    };
    valueType?: 'text' | 'select' | 'date' | 'dateTime' | 'dateMonth' | 'dateYear' | 'dateRange' | 'dateTimeRange' | 'checkbox' | 'radio' | 'radioButton' | 'switch' | 'digit' | 'treeSelect' | 'image';
    valueEnum?: Record<string, any>;
    fieldProps?: Record<string, any>;
    formItemProps?: Record<string, any>;
    order?: number;
    colSize?: number;
    initialValue?: any;
    request?: () => Promise<any>;
    render?: (text: string, record: Record<string, any>, index: number) => ReactNode;
}
interface IRowSelection {
    type: 'checkbox' | 'radio';
    selectedRowKeys?: Array<string | number>;
    defaultSelectedRowKeys?: Array<string | number>;
    /**
     * 选中项发生变化时的回调
     */
    onChange?: (selectedRowKeys: Array<string | number>, selectedRows: Array<Record<string, any>>) => void;
    /**
     * 用户手动选择/取消选择某行的回调
     */
    onSelect?: (record: Record<string, any>, selected: boolean, selectedRows: Record<string, any>[], nativeEvent: MouseEvent) => void;
    /**
     * 用户手动选择/取消选择所有行的回调
     */
    onSelectAll?: (selected: boolean, selectedRows: Record<string, any>[], changeRows: Record<string, any>[]) => void;
}
interface Iscroll {
    /**
     * 当分页、排序、筛选变化后是否滚动到表格顶部
     */
    scrollToFirstRowOnChange?: boolean;
    /**
     * 设置横向滚动，也可用于指定滚动区域的宽，可以设置为像素值，百分比，true 和 'max-content'
     */
    x?: string | number | true;
    /**
     * 	设置纵向滚动，也可用于指定滚动区域的高，可以设置为像素值
     */
    y?: string | number;
}
declare type defaultColConfig = {
    xs: 24;
    sm: 24;
    md: 12;
    lg: 12;
    xl: 8;
    xxl: 6;
};
interface Isearch {
    labelWidth?: number | 'auto';
    span?: number | defaultColConfig;
    filterType?: 'query' | 'light';
    searchText?: string;
    resetText?: string;
    submitText?: string;
    transform?: (value: any) => any;
    optionRender?: ((searchConfig: any, formProps: any, dom: any) => ReactNode[]) | false;
}
declare type Props = {
    className?: string;
    rowClassName?: (record: Record<string, any>, index: number) => string;
    style?: React.CSSProperties;
    tbodyStyle?: React.CSSProperties;
    thStyle?: React.CSSProperties;
    columns: ColumnProps[];
    border?: Boolean;
    params?: Record<string, any>;
    dataSource?: Record<string, any>[];
    request?: (params?: {
        pageSize?: number;
        current?: number;
    }, sort?: any, filter?: any) => {
        data: Record<string, any>[];
        success: boolean;
        total: number;
    };
    onLoad?: (dataSource: Record<string, any>[]) => void;
    onSubmit?: (params: Record<string, any>) => void;
    onReset?: () => void;
    rowKey: ((record: Record<string, any>) => number | string) | string;
    onRow?: (record: Record<string, any>, index: any) => Record<string, any>;
    rowSelection?: IRowSelection;
    scroll?: Iscroll;
    pagination?: false | Record<string, any>;
    formRef?: MutableRefObject<FormInstance>;
    children?: ReactNode;
    form?: FormProps;
    search?: Isearch | false;
};
declare function Table({ columns, dataSource: tableList, request, params, rowKey, onRow, className, rowClassName, rowSelection, style, tbodyStyle, thStyle, border, scroll, pagination, search, ...props }: Props): JSX.Element;
declare namespace Table {
    var defaultProps: {
        rowKey: string;
    };
}
export default Table;
